@@ -43,19 +43,18 @@ def _cli(target, source, signature_type, host, port, debug, dry_run):
     if signature_type == "http" and ff == "":
         app = create_app(target, source, signature_type)
     else:
-        ctx = parse_function_context()
-        port = ctx.port
-        if ctx.runtime == KNATIVE_FUNC:
+        _ctx = parse_function_context()
+        port = _ctx.port
+        if _ctx.runtime == KNATIVE_FUNC:
             app = create_app(target, source, signature_type)
-        elif ctx.runtime == ASYNC:
-
+        elif _ctx.runtime == ASYNC:
             signature_type = "of"
             app = create_dapr_app(target, source, signature_type, ctx)
     if dry_run:
         click.echo("Function: {}".format(target))
         click.echo("URL: http://{}:{}/".format(host, port))
         click.echo("Dry run successful, shutting down.")
-    elif ctx.runtime == ASYNC:
+    elif ff != "":
         create_dapr_server(app, port).run()
     else:
         create_server(app, debug).run(host, port)
